@@ -18,16 +18,16 @@ my $UNLOCK      = 1000;
 my $minion = Minion->new(Pg => 'postgresql://postgres@127.0.0.1:5432/postgres');
 $minion->add_task(foo => sub { });
 $minion->add_task(bar => sub { });
-$minion->reset;
+$minion->reset({all => 1});
 
 # Enqueue
 say "Clean start with $ENQUEUE jobs";
 my @parents = map { $minion->enqueue('foo') } 1 .. 5;
-my $before = time;
+my $before  = time;
 $minion->enqueue($_ % 2 ? 'foo' : 'bar' => [] => {parents => \@parents})
   for 1 .. $ENQUEUE;
 my $elapsed = time - $before;
-my $avg = sprintf '%.3f', $ENQUEUE / $elapsed;
+my $avg     = sprintf '%.3f', $ENQUEUE / $elapsed;
 say "Enqueued $ENQUEUE jobs in $elapsed seconds ($avg/s)";
 $minion->backend->pg->db->query('analyze minion_jobs');
 
@@ -42,7 +42,7 @@ sub dequeue {
       my $before = time;
       $worker->dequeue(0.5)->finish for 1 .. $DEQUEUE;
       my $elapsed = time - $before;
-      my $avg = sprintf '%.3f', $DEQUEUE / $elapsed;
+      my $avg     = sprintf '%.3f', $DEQUEUE / $elapsed;
       say "$$ finished $DEQUEUE jobs in $elapsed seconds ($avg/s)";
       $worker->unregister;
       exit;
@@ -54,7 +54,7 @@ sub dequeue {
   my $before = time;
   waitpid $_, 0 for @pids;
   my $elapsed = time - $before;
-  my $avg = sprintf '%.3f', ($DEQUEUE * $WORKERS) / $elapsed;
+  my $avg     = sprintf '%.3f', ($DEQUEUE * $WORKERS) / $elapsed;
   say
     "$WORKERS workers finished $DEQUEUE jobs each in $elapsed seconds ($avg/s)";
 }
@@ -66,7 +66,7 @@ $before = time;
 my $backend = $minion->backend;
 $backend->list_jobs(0, 1, {ids => [$_]}) for 1 .. $INFO;
 $elapsed = time - $before;
-$avg = sprintf '%.3f', $INFO / $elapsed;
+$avg     = sprintf '%.3f', $INFO / $elapsed;
 say "Received job info $INFO times in $elapsed seconds ($avg/s)";
 
 # Stats
@@ -74,7 +74,7 @@ say "Requesting stats $STATS times";
 $before = time;
 $minion->stats for 1 .. $STATS;
 $elapsed = time - $before;
-$avg = sprintf '%.3f', $STATS / $elapsed;
+$avg     = sprintf '%.3f', $STATS / $elapsed;
 say "Received stats $STATS times in $elapsed seconds ($avg/s)";
 
 # Repair
@@ -82,7 +82,7 @@ say "Repairing $REPAIR times";
 $before = time;
 $minion->repair for 1 .. $REPAIR;
 $elapsed = time - $before;
-$avg = sprintf '%.3f', $REPAIR / $elapsed;
+$avg     = sprintf '%.3f', $REPAIR / $elapsed;
 say "Repaired $REPAIR times in $elapsed seconds ($avg/s)";
 
 # Lock
@@ -91,7 +91,7 @@ $before = time;
 $minion->lock($_ % 2 ? 'foo' : 'bar', 3600, {limit => int($LOCK / 2)})
   for 1 .. $LOCK;
 $elapsed = time - $before;
-$avg = sprintf '%.3f', $LOCK / $elapsed;
+$avg     = sprintf '%.3f', $LOCK / $elapsed;
 say "Acquired locks $LOCK times in $elapsed seconds ($avg/s)";
 
 # Unlock
@@ -99,5 +99,5 @@ say "Releasing locks $UNLOCK times";
 $before = time;
 $minion->unlock($_ % 2 ? 'foo' : 'bar') for 1 .. $UNLOCK;
 $elapsed = time - $before;
-$avg = sprintf '%.3f', $UNLOCK / $elapsed;
+$avg     = sprintf '%.3f', $UNLOCK / $elapsed;
 say "Releasing locks $UNLOCK times in $elapsed seconds ($avg/s)";
